@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.1';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '3.1.2';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -344,8 +344,10 @@ sub configure {
             'allow_dirty' => 'cpanfile',  # ignore cpanfile because we copy it back from release
         }],
         ['Git::Commit' => {
-            'allow_dirty' => 'cpanfile',  # add cpanfile because we copy it back from release
-            'allow_dirty' => 'Changes',   # add cpanfile because its modified by [NextRelease]
+            'allow_dirty' => [
+                'cpanfile',  # add cpanfile because we copy it back from release
+                'Changes',   # add Changes because it's modified by [NextRelease]
+            ],
             'commit_msg' => 'Release %v%n%n%c',
         }],
         ['Git::Tag' => {
@@ -364,7 +366,7 @@ __PACKAGE__->meta->make_immutable;
 {
     package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
     # ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.1.1';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '3.1.2';
 use Moose;
     use namespace::autoclean;
 
@@ -412,7 +414,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 3.1.1
+version 3.1.2
 
 =head1 SYNOPSIS
 
